### Name: mixFdr
### Title: Fit a mixture model and use it to estimate fdr/FDR/effect sizes
### Aliases: mixFdr
### Keywords: models smooth

### ** Examples


## A simple workflow

z = c(rnorm(10000, 0.1, 1.2), rnorm(1000, 3, 1)) # null, alternative
m = mixFdr(z, theonull = TRUE)

# uh-oh, warning
# Just visually, the fit is not so good near the center
# Let's try an empirical null 

m = mixFdr(z)

# Better. But see how the effect size estimate changes with noiseSD. 

# We usually want:
m$fdr
m$effectSize
m$FDRTwoSided

# Suppose we have data with known noise level 1

 z = c(rnorm(1000), rnorm(100,3,1))
 m = mixFdr(z, J = 3, noiseSD = 1)
 delta = m$effectSize
 fdrs = m$fdr
 
# Suppose we wanted fdr and effect size curves
# then we could do

 s = seq(-5,5,by=0.01)
 effCurve = effectSize(s,m)[,1]
 fdrCurve = fdrMixModel(s,m,abs(m$mu - m$mu[1])<=0.2) # this tells it which indices to consider null

# compare to the Bayes estimator for this problem
 mTrue = list(pi = c(10,1)/11, mu = c(0,3), sig = c(1,1))
# note that the model parameters are in terms of the MARGINAL not of the prior
 trueEff = effectSize(s,mTrue)[,1]
 trueFdr = fdrMixModel(s,mTrue,c(TRUE,FALSE))
 par(mfrow = c(2,1))
 plot(s, trueEff, t = 'l', main = "Effect Size - Black is true", xlab = "z", ylab = "E(delta|z)", ylim = c(-3,3))
 lines(s, effCurve, col = 2)
 plot(s, trueFdr, t = 'l', main = "fdr - Black is true", xlab = "z", ylab = "fdr", ylim = c(0,1))
 lines(s, fdrCurve, col = 2)




